@@ -7,14 +7,13 @@
 # Usage: sh find_repeated_words.sh [file...]
 #
 
-MANWIDTH=2000
-
 for file in "$@" ; do 
-    words=$(man -l "$file" 2> /dev/null | col -b | \
+    words=$(MANWIDTH=2000 man -l "$file" 2> /dev/null | col -b | \
 	tr ' \008' '\012' | sed -e '/^$/d' | \
-	awk 'BEGIN {p=""} {if (p==$0) print p; p=$0 }' | \
+	sed 's/ *$//' | 
+	awk 'BEGIN {p=""} {if (p==$0) print p; p=$0}' | \
 	grep '[a-zA-Z]' | tr '\012' ' ')
-    if test -n "X$words"; then
+    if test -n "$words"; then
         echo "$file: $words"
     fi
 done
